summaryrefslogtreecommitdiff
path: root/src/engine/home.asm
diff options
context:
space:
mode:
Diffstat (limited to 'src/engine/home.asm')
-rw-r--r--src/engine/home.asm16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/engine/home.asm b/src/engine/home.asm
index 1425359..ff07a17 100644
--- a/src/engine/home.asm
+++ b/src/engine/home.asm
@@ -4453,11 +4453,11 @@ Func_16f6: ; 16f6 (0:16f6)
xor a
ld [wccec], a
ld [wEffectFunctionsFeedbackIndex], a
- ld [wcced], a
+ ld [wEffectFailed], a
ld [wIsDamageToSelf], a
ld [wccef], a
ld [wccf0], a
- ld [wccf1], a
+ ld [wNoEffectFromStatus], a
bank1call ClearNonTurnTemporaryDuelvars_CopyStatus
ret
@@ -5175,10 +5175,10 @@ Func_1bb4: ; 1bb4 (0:1bb4)
call ExchangeRNG
ret
; prints one of the ThereWasNoEffectFrom*Text if wcced contains $1,
; and WasUnsuccessfulText if wcced contains $2
Func_1bca: ; 1bca (0:1bca)
- ld a, [wcced]
+ ld a, [wEffectFailed]
or a
ret z
cp $1
@@ -9309,16 +9309,16 @@ Func_30a6: ; 30a6 (0:30a6)
; similar to DrawYourOrOppPlayArea (bank 2) except it also draws a wide text box.
; this is because bank 2's DrawYourOrOppPlayArea is supposed to come from the Check Menu,
; so the text box is always already there.
-DrawYourOrOppPlayArea_Bank0: ; 30bc (0:30bc)
+DrawYourOrOppPlayAreaScreen_Bank0: ; 30bc (0:30bc)
ld a, h
ld [wCheckMenuPlayAreaWhichDuelist], a
ld a, l
ld [wCheckMenuPlayAreaWhichLayout], a
ldh a, [hBankROM]
push af
- ld a, BANK(_DrawYourOrOppPlayArea)
+ ld a, BANK(_DrawYourOrOppPlayAreaScreen)
call BankswitchROM
- call _DrawYourOrOppPlayArea
+ call _DrawYourOrOppPlayAreaScreen
call DrawWideTextBox
pop af
call BankswitchROM
@@ -5175,10 +5175,10 @@ Func_1bb4: ; 1bb4 (0:1bb4)
call ExchangeRNG
ret
-; prints one of the ThereWasNoEffectFrom*Text if wcced contains $1,
-; and WasUnsuccessfulText if wcced contains $2
+; prints one of the ThereWasNoEffectFrom*Text if wEffectFailed contains EFFECT_FAILED_NO_EFFECT,
+; and prints WasUnsuccessfulText if wEffectFailed contains EFFECT_FAILED_UNSUCCESSFUL
Func_1bca: ; 1bca (0:1bca)